pub struct FileIdentity {
pub dev: u64,
pub ino: u64,
}Expand description
Identifies the file, not the path. Used on resume to detect that the file we recorded progress against has been replaced by a different one.
Fields
dev: u64ino: u64Trait Implementations
Sourceimpl Clone for FileIdentity
impl Clone for FileIdentity
Sourcefn clone(&self) -> FileIdentity
fn clone(&self) -> FileIdentity
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for FileIdentity
Sourceimpl Debug for FileIdentity
impl Debug for FileIdentity
impl Eq for FileIdentity
Sourceimpl PartialEq for FileIdentity
impl PartialEq for FileIdentity
impl StructuralPartialEq for FileIdentity