pub fn classify(
primary: &RemoteInfo,
candidate: &RemoteInfo,
has_checksum: bool,
) -> AdmissionExpand description
Decide whether candidate may contribute bytes to the same file as
primary.
pub fn classify(
primary: &RemoteInfo,
candidate: &RemoteInfo,
has_checksum: bool,
) -> AdmissionDecide whether candidate may contribute bytes to the same file as
primary.