pub struct Reconciled {
pub ranges: Vec<RangeRecord>,
pub trusted_bytes: u64,
pub discarded_bytes: u64,
pub notes: Vec<String>,
}Fields
ranges: Vec<RangeRecord>trusted_bytes: u64Bytes we are confident about and will not fetch again.
discarded_bytes: u64Bytes the database claimed but we chose to re-download.
notes: Vec<String>Trait Implementations
Sourceimpl Clone for Reconciled
impl Clone for Reconciled
Sourcefn clone(&self) -> Reconciled
fn clone(&self) -> Reconciled
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for Reconciled
impl RefUnwindSafe for Reconciled
impl Send for Reconciled
impl Sync for Reconciled
impl Unpin for Reconciled
impl UnsafeUnpin for Reconciled
impl UnwindSafe for Reconciled