pub struct DownloadRecord {Show 22 fields
pub id: String,
pub original_url: String,
pub resolved_url: Option<String>,
pub mirrors: Vec<String>,
pub destination: String,
pub filename: String,
pub total_size: Option<u64>,
pub etag: Option<String>,
pub last_modified: Option<String>,
pub content_type: Option<String>,
pub accept_ranges: bool,
pub expected_checksum: Option<String>,
pub checksum_algorithm: Option<String>,
pub file_cookie: String,
pub file_dev: Option<u64>,
pub file_ino: Option<u64>,
pub durable_bytes: u64,
pub status: Status,
pub error: Option<String>,
pub created_at: i64,
pub updated_at: i64,
pub completed_at: Option<i64>,
}Fields
id: Stringoriginal_url: Stringresolved_url: Option<String>mirrors: Vec<String>destination: Stringfilename: Stringtotal_size: Option<u64>etag: Option<String>last_modified: Option<String>content_type: Option<String>accept_ranges: boolexpected_checksum: Option<String>checksum_algorithm: Option<String>Random token minted when the destination file is created. Together with dev/ino it proves the file on disk is the one we were downloading into.
file_dev: Option<u64>file_ino: Option<u64>durable_bytes: u64status: Statuserror: Option<String>created_at: i64updated_at: i64completed_at: Option<i64>Trait Implementations
Sourceimpl Clone for DownloadRecord
impl Clone for DownloadRecord
Sourcefn clone(&self) -> DownloadRecord
fn clone(&self) -> DownloadRecord
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DownloadRecord
impl Debug for DownloadRecord