pub async fn run(ctx: Arc<WorkerCtx>, worker_id: usize) -> WorkerOutcomeExpand description
Pull ranges until there are none left, the download is cancelled, or a non-recoverable error occurs.
pub async fn run(ctx: Arc<WorkerCtx>, worker_id: usize) -> WorkerOutcomePull ranges until there are none left, the download is cancelled, or a non-recoverable error occurs.